/*global module:false*/
module.exports = function(grunt) {

  grunt.initConfig({
    pkg: grunt.file.readJSON('package.json'),
    concurrent: {
      dev: {
        tasks: ['nodemon', 'watch'],
        options: {
          logConcurrentOutput: true
        }
      }
    },
    jshint: {
      options: {
        curly: true,
        eqeqeq: true,
        immed: true,
        latedef: true,
        newcap: true,
        noarg: true,
        sub: true,
        undef: true,
        unused: true,
        boss: true,
        eqnull: true,
        globals: {
          jQuery: true
        }
      },
      source: {
        src: ['touch-api-client.js', './js/**/*']
      }
    },
    watch: {
      gruntfile: {
        files: '<%= jshint.gruntfile.src %>',
        tasks: ['jshint:gruntfile']
      },
      source: {
        files: '<%= jshint.source.src %>',
        tasks: [/*'jshint:source',*/'browserify:standalone', 'uglify:standalone']
      }
    },
    nodemon: {
      dev: {
        script: './server.js',
        nodeArgs: ['--debug'],
        options: {
          env: {
            PORT: 8880,
            HOST: 'localhost:8880',
            DEBUG: true
          },
          callback: function (nodemon) {
            nodemon.on('log', function (event) {
              console.log(event.colour);
            });
          }
        }
      }
    },
    browserify: {
      standalone: {
        src: [ '<%= pkg.name %>.js' ],
        dest: 'dist/<%= pkg.name %>.js',
        options: {
          browserifyOptions: {
            standalone: 'TouchApiClient',
            debug: true
          }
        }
      },
    },
    uglify: {
      standalone: {
        files: {
          'dist/<%= pkg.name %>.min.js': ['dist/<%= pkg.name %>.js']
        },
        mangle: false,
        sourceMap: true
      }
    },
    bump: {
      options: {
        files: ['package.json','bower.json'],
        updateConfigs: ['pkg'],
        commitFiles: ['-a'],
        pushTo: 'origin',
        tagName: '%VERSION%'
      }
    },
    'npm-publish': {
      options: {
        abortIfDirty: true
      }
    }
  });

  grunt.loadNpmTasks('grunt-browserify');
  grunt.loadNpmTasks('grunt-bump');
  grunt.loadNpmTasks('grunt-concurrent');
  grunt.loadNpmTasks('grunt-contrib-jshint');
  grunt.loadNpmTasks('grunt-contrib-nodeunit');
  grunt.loadNpmTasks('grunt-contrib-watch');
  grunt.loadNpmTasks('grunt-contrib-uglify');
  grunt.loadNpmTasks('grunt-nodemon');
  grunt.loadNpmTasks('grunt-npm');

  grunt.registerTask('default', ['jshint']);
  grunt.registerTask('dev', 'concurrent:dev');
  grunt.registerTask('build', ['browserify', 'uglify']);
  grunt.registerTask('release', ['build', 'bump', 'npm-publish']);
};
