/*jslint node: true */
'use strict';

/*
 * Copyright 2014 the original author or authors
 * @license MIT, see LICENSE for details
 *
 * @author Artem Abashev
 */

var TouchApiClient = require('./abstract.js');

var OAuthClient2 = function(config, tokenProvider) {
  TouchApiClient.call(this, config, tokenProvider);
  this._config.path = '/oauth2/';
  this._config.contentType = 'application/x-www-form-urlencoded';
};

OAuthClient2.prototype = Object.create(TouchApiClient.prototype);
OAuthClient2.prototype.constructor = TouchApiClient;

OAuthClient2.prototype.getSession = function() {
  return this._request('session', 'GET');
};

OAuthClient2.prototype.getTokenWithCredentials = function(clientId, username, password) {
  var body = {
    grant_type: 'password',
    client_id: clientId,
    username: username,
    password: password
  };
  return this._request('token', 'POST', body, null, true);
};

OAuthClient2.prototype.getAuthConfirmUrl = function(ticketId, params) {
  return this._getUrl('auth/confirm/' + encodeURIComponent(ticketId), params);
};

OAuthClient2.prototype.getAuthRejectUrl = function(params) {
  return this._getUrl('auth/reject', params);
};

OAuthClient2.prototype.getTokenAuthorizeUrl = function(clientId, redirectUrl, scope) {
  return this._getUrl('auth', {
    response_type: 'token',
    client_id: clientId,
    redirect_uri: redirectUrl,
    scope: scope
  });
};

module.exports = OAuthClient2;
